==> qiho-center-api-2.7.2-hrd-20201029.024308-16-sources.jar: com/qiho/center/api/dto/AfterSaleOrderDto.java <==
package com.qiho.center.api.dto;

import java.util.Date;
import java.util.List;

/**
 * Created by danke on 2017/10/9.
 * 售后子订单dto
 */
public class AfterSaleOrderDto extends BaseDto{

    /** id */
    private String id;

    /** 订单id */
    private String orderId;

    /** 售后子订单id */
    private String afterSaleId;

    /** 售后订单状态 */
    private String afterSaleStatus;

    /** 售后子订单 **/
    private String afterSaleSubStatus;

    /** 交易账号 */
    private String account;

    /** 退运费金额 */
    private Integer refreightAmt;

    /** 退款金额 */
    private Integer refundAmt;

    /** 买家姓名 */
    private String consumerName;

    /** 买家电话 */
    private String mobile;

    /** 售后子订单原因 */
    private String afterSaleReason;

    /** 订单支付类型,用于匹配退款方式 */
    private String payType;

    /** 售后子订单类型 */
    private String afterSaleType;

    /** 记录最后更新时间 */
    private Date gmtModified;

    /** 记录创建时间 */
    private Date gmtCreate;

    /** 物流单号 */
    private String postId;

    /** 物流公司 */
    private String logisticsName;

    /** 备注 */
    private String remark;

    /** 操作详情 */
    private List<AfterSaleStageDto> detailStage;

    /**
     * 商家地址
     */
    private String merchantAddress;

    /**
     * 付款截图
     */
    private String payRecordUrl;

    /**
     * 物流状态
     */
    private String logisticsStatus;

    /**
     * 商家说明
     */
    private String merchantDesc;

    /** 扩展字段,json串 **/
    private String metaValue;

    /**
     * 订单创建时间
     */
    private Date orderGmtCreate;

    /**
     * 发货物流状态
     */
    private String sendLogisticsStatus;

    /**
     * 订单金额
     */
    private Long orderAmt;

    /**
     * 退款金额
     */
    private Long refundAmount;

    /**
     * 自动确认倒计时
     */
    private Long countdownTime;

    /**
     * 商品id
     */
    private Long itemId;

    /**
     * 商品名称
     */
    private String itemName;

    /**
     * 商品链接
     */
    private String itemUrl;

    /**
     * 物流状态
     */
    private String logisticStatus;

    /**
     * 结算状态
     */
    private Integer closeStatus;

    public Date getOrderGmtCreate() {
        return orderGmtCreate;
    }

    public void setOrderGmtCreate(Date orderGmtCreate) {
        this.orderGmtCreate = orderGmtCreate;
    }

    public String getSendLogisticsStatus() {
        return sendLogisticsStatus;
    }

    public void setSendLogisticsStatus(String sendLogisticsStatus) {
        this.sendLogisticsStatus = sendLogisticsStatus;
    }

    public Long getOrderAmt() {
        return orderAmt;
    }

    public void setOrderAmt(Long orderAmt) {
        this.orderAmt = orderAmt;
    }

    public Long getRefundAmount() {
        return refundAmount;
    }

    public void setRefundAmount(Long refundAmount) {
        this.refundAmount = refundAmount;
    }

    public Long getCountdownTime() {
        return countdownTime;
    }

    public void setCountdownTime(Long countdownTime) {
        this.countdownTime = countdownTime;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemUrl() {
        return itemUrl;
    }

    public void setItemUrl(String itemUrl) {
        this.itemUrl = itemUrl;
    }

    public String getLogisticStatus() {
        return logisticStatus;
    }

    public void setLogisticStatus(String logisticStatus) {
        this.logisticStatus = logisticStatus;
    }

    public Integer getCloseStatus() {
        return closeStatus;
    }

    public void setCloseStatus(Integer closeStatus) {
        this.closeStatus = closeStatus;
    }

    public String getAfterSaleSubStatus() {
        return afterSaleSubStatus;
    }

    public void setAfterSaleSubStatus(String afterSaleSubStatus) {
        this.afterSaleSubStatus = afterSaleSubStatus;
    }

    public String getMerchantAddress() {
        return merchantAddress;
    }

    public void setMerchantAddress(String merchantAddress) {
        this.merchantAddress = merchantAddress;
    }

    public String getPayRecordUrl() {
        return payRecordUrl;
    }

    public void setPayRecordUrl(String payRecordUrl) {
        this.payRecordUrl = payRecordUrl;
    }

    public String getLogisticsStatus() {
        return logisticsStatus;
    }

    public void setLogisticsStatus(String logisticsStatus) {
        this.logisticsStatus = logisticsStatus;
    }

    public String getMerchantDesc() {
        return merchantDesc;
    }

    public void setMerchantDesc(String merchantDesc) {
        this.merchantDesc = merchantDesc;
    }

    public String getAfterSaleId() {
        return afterSaleId;
    }

    public void setAfterSaleId(String afterSaleId) {
        this.afterSaleId = afterSaleId;
    }

    public String getAfterSaleStatus() {
        return afterSaleStatus;
    }

    public void setAfterSaleStatus(String afterSaleStatus) {
        this.afterSaleStatus = afterSaleStatus;
    }

    public Integer getRefreightAmt() {
        return refreightAmt;
    }

    public void setRefreightAmt(Integer refreightAmt) {
        this.refreightAmt = refreightAmt;
    }

    public Integer getRefundAmt() {
        return refundAmt;
    }

    public void setRefundAmt(Integer refundAmt) {
        this.refundAmt = refundAmt;
    }

    public String getAfterSaleReason() {
        return afterSaleReason;
    }

    public void setAfterSaleReason(String afterSaleReason) {
        this.afterSaleReason = afterSaleReason;
    }

    public String getAfterSaleType() {
        return afterSaleType;
    }

    public void setAfterSaleType(String afterSaleType) {
        this.afterSaleType = afterSaleType;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getLogisticsName() {
        return logisticsName;
    }

    public void setLogisticsName(String logisticsName) {
        this.logisticsName = logisticsName;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getMetaValue() {
        return metaValue;
    }

    public void setMetaValue(String metaValue) {
        this.metaValue = metaValue;
    }

    public List<AfterSaleStageDto> getDetailStage() {
        return detailStage;
    }

    public void setDetailStage(List<AfterSaleStageDto> detailStage) {
        this.detailStage = detailStage;
    }
}

==> qiho-center-api-2.7.25-hrd-20201223.072435-7-sources.jar: com/qiho/center/api/dto/AfterSaleOrderDto.java <==
package com.qiho.center.api.dto;

import java.util.Date;
import java.util.List;

/**
 * Created by danke on 2017/10/9.
 * 售后子订单dto
 */
public class AfterSaleOrderDto extends BaseDto{

    /** id */
    private String id;

    /** 订单id */
    private String orderId;

    /** 售后子订单id */
    private String afterSaleId;

    /** 售后订单状态 */
    private String afterSaleStatus;

    /** 售后子订单 **/
    private String afterSaleSubStatus;

    /** 交易账号 */
    private String account;

    /** 退运费金额 */
    private Integer refreightAmt;

    /** 退款金额 */
    private Integer refundAmt;

    /** 买家姓名 */
    private String consumerName;

    /** 买家电话 */
    private String mobile;

    /** 售后子订单原因 */
    private String afterSaleReason;

    /** 订单支付类型,用于匹配退款方式 */
    private String payType;

    /** 售后子订单类型 */
    private String afterSaleType;

    /** 记录最后更新时间 */
    private Date gmtModified;

    /** 记录创建时间 */
    private Date gmtCreate;

    /** 物流单号 */
    private String postId;

    /** 物流公司 */
    private String logisticsName;

    /** 备注 */
    private String remark;

    /** 操作详情 */
    private List<AfterSaleStageDto> detailStage;

    /**
     * 商家地址
     */
    private String merchantAddress;

    /**
     * 付款截图
     */
    private String payRecordUrl;

    /**
     * 物流状态
     */
    private String logisticsStatus;

    /**
     * 商家说明
     */
    private String merchantDesc;

    /** 扩展字段,json串 **/
    private String metaValue;

    /**
     * 订单创建时间
     */
    private Date orderGmtCreate;

    /**
     * 发货物流状态
     */
    private String sendLogisticsStatus;

    /**
     * 订单金额
     */
    private Long orderAmt;

    /**
     * 退款金额
     */
    private Long refundAmount;

    /**
     * 自动确认倒计时
     */
    private Long countdownTime;

    /**
     * 商品id
     */
    private Long itemId;

    /**
     * 商品名称
     */
    private String itemName;

    /**
     * 商品链接
     */
    private String itemUrl;

    /**
     * 物流状态
     */
    private String logisticStatus;

    /**
     * 结算状态
     */
    private Integer closeStatus;

    /**
     * 下次自动同意时间
     */
    private Date nextAutoAgreeTime;

    /**
     * 操作人id
     */
    private Long operatorId;

    /**
     * 操作人
     */
    private String operator;

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public Date getNextAutoAgreeTime() {
        return nextAutoAgreeTime;
    }

    public void setNextAutoAgreeTime(Date nextAutoAgreeTime) {
        this.nextAutoAgreeTime = nextAutoAgreeTime;
    }

    public Date getOrderGmtCreate() {
        return orderGmtCreate;
    }

    public void setOrderGmtCreate(Date orderGmtCreate) {
        this.orderGmtCreate = orderGmtCreate;
    }

    public String getSendLogisticsStatus() {
        return sendLogisticsStatus;
    }

    public void setSendLogisticsStatus(String sendLogisticsStatus) {
        this.sendLogisticsStatus = sendLogisticsStatus;
    }

    public Long getOrderAmt() {
        return orderAmt;
    }

    public void setOrderAmt(Long orderAmt) {
        this.orderAmt = orderAmt;
    }

    public Long getRefundAmount() {
        return refundAmount;
    }

    public void setRefundAmount(Long refundAmount) {
        this.refundAmount = refundAmount;
    }

    public Long getCountdownTime() {
        return countdownTime;
    }

    public void setCountdownTime(Long countdownTime) {
        this.countdownTime = countdownTime;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemUrl() {
        return itemUrl;
    }

    public void setItemUrl(String itemUrl) {
        this.itemUrl = itemUrl;
    }

    public String getLogisticStatus() {
        return logisticStatus;
    }

    public void setLogisticStatus(String logisticStatus) {
        this.logisticStatus = logisticStatus;
    }

    public Integer getCloseStatus() {
        return closeStatus;
    }

    public void setCloseStatus(Integer closeStatus) {
        this.closeStatus = closeStatus;
    }

    public String getAfterSaleSubStatus() {
        return afterSaleSubStatus;
    }

    public void setAfterSaleSubStatus(String afterSaleSubStatus) {
        this.afterSaleSubStatus = afterSaleSubStatus;
    }

    public String getMerchantAddress() {
        return merchantAddress;
    }

    public void setMerchantAddress(String merchantAddress) {
        this.merchantAddress = merchantAddress;
    }

    public String getPayRecordUrl() {
        return payRecordUrl;
    }

    public void setPayRecordUrl(String payRecordUrl) {
        this.payRecordUrl = payRecordUrl;
    }

    public String getLogisticsStatus() {
        return logisticsStatus;
    }

    public void setLogisticsStatus(String logisticsStatus) {
        this.logisticsStatus = logisticsStatus;
    }

    public String getMerchantDesc() {
        return merchantDesc;
    }

    public void setMerchantDesc(String merchantDesc) {
        this.merchantDesc = merchantDesc;
    }

    public String getAfterSaleId() {
        return afterSaleId;
    }

    public void setAfterSaleId(String afterSaleId) {
        this.afterSaleId = afterSaleId;
    }

    public String getAfterSaleStatus() {
        return afterSaleStatus;
    }

    public void setAfterSaleStatus(String afterSaleStatus) {
        this.afterSaleStatus = afterSaleStatus;
    }

    public Integer getRefreightAmt() {
        return refreightAmt;
    }

    public void setRefreightAmt(Integer refreightAmt) {
        this.refreightAmt = refreightAmt;
    }

    public Integer getRefundAmt() {
        return refundAmt;
    }

    public void setRefundAmt(Integer refundAmt) {
        this.refundAmt = refundAmt;
    }

    public String getAfterSaleReason() {
        return afterSaleReason;
    }

    public void setAfterSaleReason(String afterSaleReason) {
        this.afterSaleReason = afterSaleReason;
    }

    public String getAfterSaleType() {
        return afterSaleType;
    }

    public void setAfterSaleType(String afterSaleType) {
        this.afterSaleType = afterSaleType;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getLogisticsName() {
        return logisticsName;
    }

    public void setLogisticsName(String logisticsName) {
        this.logisticsName = logisticsName;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getMetaValue() {
        return metaValue;
    }

    public void setMetaValue(String metaValue) {
        this.metaValue = metaValue;
    }

    public List<AfterSaleStageDto> getDetailStage() {
        return detailStage;
    }

    public void setDetailStage(List<AfterSaleStageDto> detailStage) {
        this.detailStage = detailStage;
    }
}
